pub struct swapMultiPermit2Call {
pub permit2: <permit2Info as SolType>::RustType,
pub inputs: Vec<<inputTokenInfo as SolType>::RustType>,
pub outputs: Vec<<outputTokenInfo as SolType>::RustType>,
pub valueOutMin: U256,
pub pathDefinition: Bytes,
pub executor: Address,
pub referralCode: u32,
}Expand description
Function with signature swapMultiPermit2((address,uint256,uint256,bytes),(address,uint256,address)[],(address,uint256,address)[],uint256,bytes,address,uint32) and selector 0x080c25b3.
function swapMultiPermit2(OdosRouterV2.permit2Info memory permit2, OdosRouterV2.inputTokenInfo[] memory inputs, OdosRouterV2.outputTokenInfo[] memory outputs, uint256 valueOutMin, bytes memory pathDefinition, address executor, uint32 referralCode) external payable returns (uint256[] memory amountsOut);Fields
permit2: <permit2Info as SolType>::RustTypeinputs: Vec<<inputTokenInfo as SolType>::RustType>outputs: Vec<<outputTokenInfo as SolType>::RustType>valueOutMin: U256pathDefinition: Bytesexecutor: AddressreferralCode: u32Trait Implementations
Sourceimpl Clone for swapMultiPermit2Call
impl Clone for swapMultiPermit2Call
Sourcefn clone(&self) -> swapMultiPermit2Call
fn clone(&self) -> swapMultiPermit2Call
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl SolCall for swapMultiPermit2Call
impl SolCall for swapMultiPermit2Call
Sourceconst SIGNATURE: &'static str = "swapMultiPermit2((address,uint256,uint256,bytes),(address,uint256,address)[],(address,uint256,address)[],uint256,bytes,address,uint32)"
const SIGNATURE: &'static str = "swapMultiPermit2((address,uint256,uint256,bytes),(address,uint256,address)[],(address,uint256,address)[],uint256,bytes,address,uint32)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (permit2Info, Array<inputTokenInfo>, Array<outputTokenInfo>, Uint<256>, Bytes, Address, Uint<32>)
type Parameters<'a> = (permit2Info, Array<inputTokenInfo>, Array<outputTokenInfo>, Uint<256>, Bytes, Address, Uint<32>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<swapMultiPermit2Call as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<swapMultiPermit2Call as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (Array<Uint<256>>,)
type ReturnTuple<'a> = (Array<Uint<256>>,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<swapMultiPermit2Call as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<swapMultiPermit2Call as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.