pub struct swapCall {
pub tokenInfo: <swapTokenInfo as SolType>::RustType,
pub pathDefinition: Bytes,
pub executor: Address,
pub referralInfo: <swapReferralInfo as SolType>::RustType,
}Expand description
Function with signature swap((address,uint256,address,address,uint256,uint256,address),bytes,address,(uint64,uint64,address)) and selector 0x30f80b4c.
function swap(IOdosRouterV3.swapTokenInfo memory tokenInfo, bytes memory pathDefinition, address executor, IOdosRouterV3.swapReferralInfo memory referralInfo) external payable returns (uint256 amountOut);Fields
tokenInfo: <swapTokenInfo as SolType>::RustTypepathDefinition: Bytesexecutor: AddressreferralInfo: <swapReferralInfo as SolType>::RustTypeTrait Implementations
Sourceimpl SolCall for swapCall
impl SolCall for swapCall
Sourceconst SIGNATURE: &'static str = "swap((address,uint256,address,address,uint256,uint256,address),bytes,address,(uint64,uint64,address))"
const SIGNATURE: &'static str = "swap((address,uint256,address,address,uint256,uint256,address),bytes,address,(uint64,uint64,address))"
The function’s ABI signature.
Sourcetype Parameters<'a> = (swapTokenInfo, Bytes, Address, swapReferralInfo)
type Parameters<'a> = (swapTokenInfo, Bytes, Address, swapReferralInfo)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<swapCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<swapCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (Uint<256>,)
type ReturnTuple<'a> = (Uint<256>,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<swapCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<swapCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.