pub struct ValidatedAgentSwapRequest {
pub chain: Chain,
pub input_token: Address,
pub input_amount: U256,
pub output_token: Address,
pub signer: Address,
pub recipient: Address,
pub slippage: Slippage,
pub referral: ReferralCode,
pub compact: bool,
pub simple: bool,
pub disable_rfqs: bool,
}Expand description
Validated single-token swap request with typed values ready for execution.
Fields
chain: Chaininput_token: Addressinput_amount: U256output_token: Addresssigner: Addressrecipient: Addressslippage: Slippagereferral: ReferralCodecompact: boolsimple: booldisable_rfqs: boolImplementations
Sourceimpl ValidatedAgentSwapRequest
impl ValidatedAgentSwapRequest
Sourcepub fn quote_request(&self) -> QuoteRequest
pub fn quote_request(&self) -> QuoteRequest
Build an Odos quote request from the validated swap inputs.
Sourcepub fn swap_builder<'a>(&self, client: &'a OdosClient) -> SwapBuilder<'a>
pub fn swap_builder<'a>(&self, client: &'a OdosClient) -> SwapBuilder<'a>
Build a configured high-level swap builder from the validated request.