pub struct QuoteSummary {Show 17 fields
pub chain_id: u64,
pub chain_name: String,
pub signer: String,
pub recipient: String,
pub from_token: String,
pub from_amount: String,
pub to_token: String,
pub to_amount: String,
pub slippage_percent: f64,
pub path_id: String,
pub price_impact_percent: f64,
pub gas_estimate: f64,
pub gas_estimate_value: f64,
pub net_out_value: f64,
pub partner_fee_percent: f64,
pub gwei_per_gas: f64,
pub warnings: Vec<String>,
}Expand description
Compact quote summary intended for tool outputs and confirmation prompts.
Fields
chain_id: u64chain_name: Stringsigner: Stringrecipient: Stringfrom_token: Stringfrom_amount: Stringto_token: Stringto_amount: Stringslippage_percent: f64path_id: Stringprice_impact_percent: f64gas_estimate: f64gas_estimate_value: f64net_out_value: f64partner_fee_percent: f64gwei_per_gas: f64warnings: Vec<String>Trait Implementations
Sourceimpl Clone for QuoteSummary
impl Clone for QuoteSummary
Sourcefn clone(&self) -> QuoteSummary
fn clone(&self) -> QuoteSummary
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for QuoteSummary
impl Debug for QuoteSummary
Sourceimpl<'de> Deserialize<'de> for QuoteSummary
impl<'de> Deserialize<'de> for QuoteSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for QuoteSummary
impl PartialEq for QuoteSummary
Sourcefn eq(&self, other: &QuoteSummary) -> bool
fn eq(&self, other: &QuoteSummary) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for QuoteSummary
impl Serialize for QuoteSummary
impl StructuralPartialEq for QuoteSummary