pub struct TransactionPlan {
pub quote: QuoteSummary,
pub transaction: TransactionSummary,
}Expand description
Complete tool-facing transaction plan including both quote context and calldata.
Fields
quote: QuoteSummarytransaction: TransactionSummaryTrait Implementations
Sourceimpl Clone for TransactionPlan
impl Clone for TransactionPlan
Sourcefn clone(&self) -> TransactionPlan
fn clone(&self) -> TransactionPlan
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TransactionPlan
impl Debug for TransactionPlan
Sourceimpl<'de> Deserialize<'de> for TransactionPlan
impl<'de> Deserialize<'de> for TransactionPlan
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for TransactionPlan
impl PartialEq for TransactionPlan
Sourcefn eq(&self, other: &TransactionPlan) -> bool
fn eq(&self, other: &TransactionPlan) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for TransactionPlan
impl Serialize for TransactionPlan
impl StructuralPartialEq for TransactionPlan