pub struct SwapEventFilter { /* private fields */ }Expand description
Builder for creating swap event filters.
This builder provides a fluent API for constructing filters to query swap events from Odos router contracts.
Example
ⓘ
use odos_sdk::events::SwapEventFilter;
let filter = SwapEventFilter::new(router_address)
.from_block(18_000_000)
.to_block(18_100_000)
.sender(sender_address);Implementations
Sourceimpl SwapEventFilter
impl SwapEventFilter
Sourcepub fn new(router_address: Address) -> Self
pub fn new(router_address: Address) -> Self
Creates a new swap event filter for the given router address.
Sourcepub fn from_block(self, block: u64) -> Self
pub fn from_block(self, block: u64) -> Self
Sets the starting block for the filter.
Sourcepub fn from_latest(self) -> Self
pub fn from_latest(self) -> Self
Sets the starting block to the latest block.
Sourcepub fn build_v2_filter(&self) -> Filter
pub fn build_v2_filter(&self) -> Filter
Builds the underlying Alloy filter for V2 Swap events.
Sourcepub fn build_v3_filter(&self) -> Filter
pub fn build_v3_filter(&self) -> Filter
Builds the underlying Alloy filter for V3 Swap events.
Sourcepub async fn get_v2_events<N, P>(
&self,
provider: &P,
) -> Result<Vec<SwapEvent>, TransportError>
pub async fn get_v2_events<N, P>( &self, provider: &P, ) -> Result<Vec<SwapEvent>, TransportError>
Gets V2 swap events from the provider.
Sourcepub async fn get_v3_events<N, P>(
&self,
provider: &P,
) -> Result<Vec<SwapEvent>, TransportError>
pub async fn get_v3_events<N, P>( &self, provider: &P, ) -> Result<Vec<SwapEvent>, TransportError>
Gets V3 swap events from the provider.